export var isIeBrowser = function () {
    var userAgent = window.navigator.userAgent;
    var msie = userAgent.indexOf('MSIE ');
    var trident = userAgent.match(/Trident.*rv:11\./);
    return msie !== -1 || trident;
};
export var userFromOgit = function (raw) {
    return {
        id: raw.account['ogit/_id'],
        name: raw.profile['ogit/Auth/Account/displayName'],
        status: raw.account['ogit/status'],
        email: raw.account['ogit/email'],
        roles: raw.profile['/roles'],
        avatar: raw.avatar,
    };
};
var hasReviewersInSession = function (session, field) {
    return !isEmpty(session[field]);
};
var configureReviewerStatus = function (session, field) {
    if (hasReviewersInSession(session, field)) {
        return session[field].split(',');
    }
    return [];
};
export var sessionFromOgit = function (raw) {
    var session = {
        id: raw['ogit/_id'],
        title: raw['ogit/title'],
        archived: raw['ogit/Knowledge/archived'] === 'true',
        handedOver: raw['/teaching_is_handedover'] === 'true',
        teachingReviewerIds: configureReviewerStatus(raw, '/teaching_reviewer_ids'),
        conversionReviewerIds: configureReviewerStatus(raw, '/conversion_reviewer_ids'),
        teachingReviewParticipantIds: configureReviewerStatus(raw, '/teaching_review_participant_ids'),
        conversionReviewParticipantIds: configureReviewerStatus(raw, '/conversion_review_participant_ids'),
    };
    if (raw['/teaching_rooms']) {
        session.teachingRooms = Number(raw['/teaching_rooms']);
    }
    if (raw['/teaching_rooms_completed']) {
        session.teachingRoomsCompleted = Number(raw['/teaching_rooms_completed']);
    }
    if (raw['/teaching_steps']) {
        session.teachingSteps = Number(raw['/teaching_steps']);
    }
    if (raw['/teaching_steps_deployed']) {
        session.teachingStepsDeployed = Number(raw['/teaching_steps_deployed']);
    }
    if (raw['/teaching_ownerId']) {
        session.teachingOwnerId = raw['/teaching_ownerId'];
    }
    if (raw['/teaching_conversion_ownerId']) {
        session.conversionOwnerId = raw['/teaching_conversion_ownerId'];
    }
    return session;
};
export var getContributorColumns = function (_a) {
    var contributors = _a.contributors, maxPerColumn = _a.maxPerColumn, graphUrl = _a.graphUrl;
    var columnIndex = 0;
    return contributors.reduce(function (columns, stats, i) {
        var userId = stats[0];
        var contributor = {
            userId: userId,
            count: stats[1],
            ranking: i + 1,
            avatarUrl: graphUrl + "/" + userId + "/picture",
        };
        if (columns[columnIndex].length >= maxPerColumn) {
            columnIndex += 1;
            columns.push([contributor]);
            return columns;
        }
        columns[columnIndex].push(contributor);
        return columns;
    }, [[]]);
};
export var formatNumber = function (n) {
    if (n >= 1000 || n <= -1000) {
        return parseFloat((n / 1000).toFixed(1)) + "k";
    }
    return String(n);
};
export var isEmpty = function (value) {
    return (value === undefined ||
        value === null ||
        (Array.isArray(value) && value.length === 0) ||
        (typeof value === 'object' && Object.keys(value).length === 0) ||
        (typeof value === 'string' && value.trim().length === 0));
};
