var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useEffect, useState } from 'react';
import moment from 'moment';
import ReactDatePicker from 'react-datepicker';
import styled from 'styled-components';
import { DatePickerStyle } from "../../global";
import { Icon } from '../Icon';
import { Button } from '../../inputs/Button';
import { PredefinedDates } from './PredefinedDates';
import { TimeControl } from './TimeControl';
import { getEndOfDay, getStartOfDay, isSameDate, isValidDateRange, } from './utils';
import { DATE_TIME_FORMAT, TIME_FORMAT, DATE_FORMAT } from './consts';
var DatePickerComponent = function (_a) {
    var initialStartDate = _a.initialStartDate, initialEndDate = _a.initialEndDate, onSave = _a.onSave;
    var _b = useState(false), open = _b[0], setOpen = _b[1];
    var _c = useState(null), startDate = _c[0], setStartDate = _c[1];
    var _d = useState(null), endDate = _d[0], setEndDate = _d[1];
    var _e = useState(null), prevEndDate = _e[0], setPrevEndDate = _e[1];
    var _f = useState(false), predefinedDate = _f[0], setPredefinedDate = _f[1];
    var _g = useState(true), timeValid = _g[0], setTimeValid = _g[1];
    var currentDate = new Date();
    var isDateValid = function () {
        return ((!startDate && !endDate) || isValidDateRange(startDate, endDate)) &&
            timeValid;
    };
    useEffect(function () {
        setStartDate(initialStartDate);
        setEndDate(initialEndDate);
    }, [initialStartDate, initialEndDate]);
    var handleDateChange = function (date) {
        var start = date[0], end = date[1];
        if (predefinedDate) {
            setStartDate(getStartOfDay(start));
            setEndDate(end ? getEndOfDay(end) : null);
        }
        else {
            setStartDate(start);
            setEndDate(end ? getEndOfDay(end) : null);
            // update time
            if (end && prevEndDate) {
                setEndDate(moment(end)
                    .set({
                    hours: moment(prevEndDate).get('hours'),
                    minutes: moment(prevEndDate).get('minutes'),
                })
                    .toDate());
            }
        }
        setPredefinedDate(false);
    };
    var handlePredefinedDateChange = function (_a) {
        var startDate = _a.startDate, endDate = _a.endDate;
        setStartDate(startDate);
        setEndDate(endDate);
        setPredefinedDate(true);
        setPrevEndDate(null);
    };
    var handleTimeChange = function (_a) {
        var startDate = _a.startDate, endDate = _a.endDate;
        setStartDate(startDate);
        setEndDate(endDate);
        setPrevEndDate(endDate);
        setPredefinedDate(false);
    };
    var handleTimeClear = function () {
        setStartDate(getStartOfDay(startDate));
        setEndDate(getEndOfDay(endDate));
        setPrevEndDate(null);
        setPredefinedDate(false);
    };
    var handleSave = function () {
        onSave({ startDate: startDate, endDate: endDate });
        setOpen(false);
    };
    var handleCancel = function () {
        setStartDate(initialStartDate);
        setEndDate(initialEndDate);
        setPrevEndDate(null);
        setOpen(false);
    };
    var handleResetDate = function () {
        setStartDate(null);
        setEndDate(null);
        setPrevEndDate(null);
        setPredefinedDate(false);
    };
    var openDatePicker = function () { return setOpen(true); };
    var formatWeekDay = function (d) { return d.substring(0, 3); };
    var getTriggerButtonText = function () {
        if (startDate && endDate) {
            return isSameDate(startDate, endDate)
                ? moment(startDate).format(DATE_FORMAT) + "/" + moment(startDate).format(TIME_FORMAT) + " - " + moment(endDate).format(TIME_FORMAT)
                : moment(startDate).format(DATE_TIME_FORMAT) + " - " + moment(endDate).format(DATE_TIME_FORMAT);
        }
        return 'Set an exact time';
    };
    return (React.createElement("div", null,
        React.createElement(DatePickerControl, null,
            React.createElement(DatePickerControlText, { onClick: openDatePicker }, getTriggerButtonText()),
            startDate && endDate ? (React.createElement(DatePickerControlIcon, { onClick: handleResetDate },
                React.createElement(Icon, { name: "times", fitted: true }))) : (React.createElement(DatePickerControlIcon, { onClick: openDatePicker },
                React.createElement(Icon, { name: "calendar-alt", fitted: true })))),
        open && (React.createElement(DatePickerModal, null,
            React.createElement(DatePickerCloseButton, { onClick: handleCancel },
                React.createElement(Icon, { name: "times" })),
            React.createElement(DatePickerRow, null,
                React.createElement(ReactDatePicker, { inline: true, selected: startDate, openToDate: endDate || currentDate, onChange: handleDateChange, startDate: startDate, endDate: endDate, selectsRange: true, monthsShown: 2, maxDate: currentDate, disabledKeyboardNavigation // removes highlighted day
                    : true, formatWeekDay: formatWeekDay, previousMonthButtonLabel: "", nextMonthButtonLabel: "" }),
                React.createElement(DatePickerPresets, null,
                    React.createElement(PredefinedDates, { startDate: startDate, endDate: endDate, onChange: handlePredefinedDateChange }))),
            React.createElement(DatePickerRow, null,
                React.createElement(DatePickerTime, null,
                    React.createElement(TimeControl, { startDate: startDate, endDate: endDate, onChange: handleTimeChange, onChangeRaw: setTimeValid, onClear: handleTimeClear }))),
            React.createElement(DatePickerFooter, null,
                React.createElement(Button, { secondary: true, onClick: handleCancel }, "Cancel"),
                React.createElement(DatePickerSaveButtonWrapper, null,
                    startDate && !endDate && (React.createElement(SaveButtonHelper, null, "Please, select end date")),
                    React.createElement(Button, { disabled: !isDateValid(), onClick: handleSave }, "Save")))))));
};
var DatePickerModal = styled('div').withConfig({ displayName: "DatePickerModal", componentId: "sc-15kz5nl" })(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  position: absolute;\n  top: 0;\n  background: #fff;\n  width: 700px;\n  box-shadow: 0 0 10px #cccccc;\n  padding: 20px 10px;\n  display: flex;\n  flex-direction: column;\n  z-index: 9999;\n"], ["\n  position: absolute;\n  top: 0;\n  background: #fff;\n  width: 700px;\n  box-shadow: 0 0 10px #cccccc;\n  padding: 20px 10px;\n  display: flex;\n  flex-direction: column;\n  z-index: 9999;\n"])));
var DatePickerRow = styled('div').withConfig({ displayName: "DatePickerRow", componentId: "sc-1e4cnag" })(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  display: flex;\n  margin-bottom: 20px;\n  border-bottom: 1px solid #ccc;\n"], ["\n  display: flex;\n  margin-bottom: 20px;\n  border-bottom: 1px solid #ccc;\n"])));
var DatePickerControl = styled('div').withConfig({ displayName: "DatePickerControl", componentId: "sc-1kufioo" })(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n  width: 300px;\n  border: 1px solid #ccc;\n  border-radius: 18px;\n  padding: 0 10px;\n"], ["\n  display: flex;\n  align-items: center;\n  width: 300px;\n  border: 1px solid #ccc;\n  border-radius: 18px;\n  padding: 0 10px;\n"])));
var DatePickerControlText = styled('button').withConfig({ displayName: "DatePickerControlText", componentId: "sc-vs8och" })(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  background: transparent;\n  border: none;\n  line-height: 35px;\n  font-size: 12px;\n  flex-grow: 1;\n  text-align: left;\n  font-style: italic;\n  white-space: nowrap;\n"], ["\n  background: transparent;\n  border: none;\n  line-height: 35px;\n  font-size: 12px;\n  flex-grow: 1;\n  text-align: left;\n  font-style: italic;\n  white-space: nowrap;\n"])));
var DatePickerControlIcon = styled('button').withConfig({ displayName: "DatePickerControlIcon", componentId: "sc-175skfl" })(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  display: inline-flex;\n  align-items: center;\n  justify-content: space-between;\n  background: transparent;\n  border: none;\n  flex-grow: 0;\n"], ["\n  display: inline-flex;\n  align-items: center;\n  justify-content: space-between;\n  background: transparent;\n  border: none;\n  flex-grow: 0;\n"])));
var DatePickerPresets = styled('div').withConfig({ displayName: "DatePickerPresets", componentId: "sc-dmjt7h" })(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  padding-left: 20px;\n  border-left: 1px solid #ccc;\n  margin-left: 20px;\n"], ["\n  padding-left: 20px;\n  border-left: 1px solid #ccc;\n  margin-left: 20px;\n"])));
var DatePickerFooter = styled('footer').withConfig({ displayName: "DatePickerFooter", componentId: "sc-1jyj0z9" })(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n"], ["\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n"])));
var DatePickerCloseButton = styled('button').withConfig({ displayName: "DatePickerCloseButton", componentId: "sc-1023hbu" })(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n  position: absolute;\n  right: 0;\n  top: 0;\n  background: transparent;\n  border: none;\n  padding: 5px;\n\n  & svg {\n    width: 15px;\n    height: 15px;\n  }\n"], ["\n  position: absolute;\n  right: 0;\n  top: 0;\n  background: transparent;\n  border: none;\n  padding: 5px;\n\n  & svg {\n    width: 15px;\n    height: 15px;\n  }\n"])));
var DatePickerSaveButtonWrapper = styled('div').withConfig({ displayName: "DatePickerSaveButtonWrapper", componentId: "sc-1fwvbnk" })(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n  display: flex;\n  align-items: center;\n"], ["\n  display: flex;\n  align-items: center;\n"])));
var SaveButtonHelper = styled('span').withConfig({ displayName: "SaveButtonHelper", componentId: "sc-brgy52" })(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n  margin-right: 20px;\n  font-style: italic;\n  font-size: 12px;\n"], ["\n  margin-right: 20px;\n  font-style: italic;\n  font-size: 12px;\n"])));
var DatePickerTime = styled('div').withConfig({ displayName: "DatePickerTime", componentId: "sc-12nmkma" })(templateObject_11 || (templateObject_11 = __makeTemplateObject(["\n  margin-bottom: 20px;\n  width: 100%;\n"], ["\n  margin-bottom: 20px;\n  width: 100%;\n"])));
var DatePickerWrapper = styled(DatePickerComponent).withConfig({ displayName: "DatePickerWrapper", componentId: "sc-1veslme" })(templateObject_12 || (templateObject_12 = __makeTemplateObject(["\n  position: relative;\n"], ["\n  position: relative;\n"])));
export var DatePicker = function (props) { return (React.createElement(React.Fragment, null,
    React.createElement(DatePickerWrapper, __assign({}, props)),
    React.createElement(DatePickerStyle, null))); };
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11, templateObject_12;
